@@ -14,9 +14,17 @@ import os
 import sys
 import subprocess
 import stat
+
 import gi
 import cairo
+
+# Attempt to load in JXL support
+try:
+     import pillow_jxl
+except ImportError:
+     pass
 from PIL import Image
+
 from azote import common
 
 # send2trash module may or may not be available
@@ -43,13 +51,22 @@ from azote.plugins import Alacritty, Xresources
 from azote.color_tools import WikiColours
 
 try:
-    gi.require_version('AppIndicator3', '0.1')
-    from gi.repository import AppIndicator3
+    try:
+        gi.require_version('AppIndicator3', '0.1')
+        from gi.repository import AppIndicator3
 
-    common.env['app_indicator'] = True
-except:
+        common.env['app_indicator'] = True
+        common.env['app_indicator_library'] = 'AppIndicator3'
+    except (ImportError, ValueError):
+        gi.require_version('AyatanaAppIndicator3', '0.1')
+        from gi.repository import AyatanaAppIndicator3 as AppIndicator3
+
+        common.env['app_indicator'] = True
+        common.env['app_indicator_library'] = 'AyatanaAppIndicator3'
+except Exception as e:
     common.env['app_indicator'] = False
-    print('libappindicator-gtk3 package not found - tray icon unavailable')
+    common.env['app_indicator_library'] = None
+    print('Neither libappindicator-gtk3 nor libayatana-appindicator3 package found - tray icon unavailable')
 
 from azote.__about__ import __version__
 
@@ -609,7 +626,7 @@ def on_about_button(button):
                         '- maim, slop (c) 2014 Dalton Nell and Contributors',
                         '- imagemagick (c) 1999-2019 ImageMagick Studio LLC',
                         '- PyYAML (c) 2017-2019 Ingy döt Net Copyright (c) 2006-2016 Kirill Simonov'])
-    dialog.set_translator_credits('xsme, Leon-Plickat (de_DE), HumanG33k (fr_FR), Andrea Frati (it_IT),\nMarcelo dos Santos (pt_BR), Aleksey Samoilov (ru_RU)')
+    dialog.set_translator_credits('zen0bit (cs_CZ), xsme, Leon-Plickat (de_DE), HumanG33k (fr_FR), Andrea Frati (it_IT),\nMarcelo dos Santos (pt_BR), Aleksey Samoilov (ru_RU), Ufuayk (tr_TR)')
     dialog.set_artists(['edskeye'])
 
     dialog.show()
